API Documentation
=================

This part of the documentation covers all the public classes and functions
in WTForms-Alchemy.

:mod:`wtforms_alchemy`
----------------------

.. module:: wtforms_alchemy
.. autoclass:: ModelForm
    :members:
.. autofunction:: model_form_factory
.. autoclass:: ModelFormMeta
    :members:
.. autofunction:: model_form_meta_factory

:mod:`wtforms_alchemy.generator`
--------------------------------

.. module:: wtforms_alchemy.generator

.. autoclass:: FormGenerator
    :members:

:mod:`wtforms_alchemy.fields`
--------------------------------

.. module:: wtforms_alchemy.fields

.. autoclass:: QuerySelectField
    :members:

.. autoclass:: QuerySelectMultipleField
    :members:


:mod:`wtforms_alchemy.utils`
----------------------------

.. module:: wtforms_alchemy.utils

.. autofunction:: translated_attributes

.. autoclass:: ClassMap
    :members:
    :special-members:
